package org.jeecg.modules.demo.dicbasicdictionaryerr.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.dicbasicdictionaryerr.entity.DicBasicDictionaryErr;
import org.jeecg.modules.demo.dicbasicdictionaryerr.service.IDicBasicDictionaryErrService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 基础词典租户错误类型
 * @Author: jeecg-boot
 * @Date:   2023-11-08
 * @Version: V1.0
 */
@Api(tags="基础词典租户错误类型")
@RestController
@RequestMapping("/dicbasicdictionaryerr/dicBasicDictionaryErr")
@Slf4j
public class DicBasicDictionaryErrController extends JeecgController<DicBasicDictionaryErr, IDicBasicDictionaryErrService> {
	@Autowired
	private IDicBasicDictionaryErrService dicBasicDictionaryErrService;
	
	/**
	 * 分页列表查询
	 *
	 * @param dicBasicDictionaryErr
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "基础词典租户错误类型-分页列表查询")
	@ApiOperation(value="基础词典租户错误类型-分页列表查询", notes="基础词典租户错误类型-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<DicBasicDictionaryErr>> queryPageList(DicBasicDictionaryErr dicBasicDictionaryErr,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<DicBasicDictionaryErr> queryWrapper = QueryGenerator.initQueryWrapper(dicBasicDictionaryErr, req.getParameterMap());
		Page<DicBasicDictionaryErr> page = new Page<DicBasicDictionaryErr>(pageNo, pageSize);
		IPage<DicBasicDictionaryErr> pageList = dicBasicDictionaryErrService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param dicBasicDictionaryErr
	 * @return
	 */
	@AutoLog(value = "基础词典租户错误类型-添加")
	@ApiOperation(value="基础词典租户错误类型-添加", notes="基础词典租户错误类型-添加")
	@RequiresPermissions("dicbasicdictionaryerr:dic_basic_dictionary_err:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody DicBasicDictionaryErr dicBasicDictionaryErr) {
		dicBasicDictionaryErrService.save(dicBasicDictionaryErr);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param dicBasicDictionaryErr
	 * @return
	 */
	@AutoLog(value = "基础词典租户错误类型-编辑")
	@ApiOperation(value="基础词典租户错误类型-编辑", notes="基础词典租户错误类型-编辑")
	@RequiresPermissions("dicbasicdictionaryerr:dic_basic_dictionary_err:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody DicBasicDictionaryErr dicBasicDictionaryErr) {
		dicBasicDictionaryErrService.updateById(dicBasicDictionaryErr);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "基础词典租户错误类型-通过id删除")
	@ApiOperation(value="基础词典租户错误类型-通过id删除", notes="基础词典租户错误类型-通过id删除")
	@RequiresPermissions("dicbasicdictionaryerr:dic_basic_dictionary_err:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		dicBasicDictionaryErrService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "基础词典租户错误类型-批量删除")
	@ApiOperation(value="基础词典租户错误类型-批量删除", notes="基础词典租户错误类型-批量删除")
	@RequiresPermissions("dicbasicdictionaryerr:dic_basic_dictionary_err:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.dicBasicDictionaryErrService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "基础词典租户错误类型-通过id查询")
	@ApiOperation(value="基础词典租户错误类型-通过id查询", notes="基础词典租户错误类型-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<DicBasicDictionaryErr> queryById(@RequestParam(name="id",required=true) String id) {
		DicBasicDictionaryErr dicBasicDictionaryErr = dicBasicDictionaryErrService.getById(id);
		if(dicBasicDictionaryErr==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(dicBasicDictionaryErr);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param dicBasicDictionaryErr
    */
    @RequiresPermissions("dicbasicdictionaryerr:dic_basic_dictionary_err:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, DicBasicDictionaryErr dicBasicDictionaryErr) {
        return super.exportXls(request, dicBasicDictionaryErr, DicBasicDictionaryErr.class, "基础词典租户错误类型");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("dicbasicdictionaryerr:dic_basic_dictionary_err:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, DicBasicDictionaryErr.class);
    }

}
