package org.jeecg.modules.demo.diccapitaltenant.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.diccapitaltenant.entity.DicCapitalTenant;
import org.jeecg.modules.demo.diccapitaltenant.service.IDicCapitalTenantService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 首都租户
 * @Author: jeecg-boot
 * @Date:   2023-11-08
 * @Version: V1.0
 */
@Api(tags="首都租户")
@RestController
@RequestMapping("/diccapitaltenant/dicCapitalTenant")
@Slf4j
public class DicCapitalTenantController extends JeecgController<DicCapitalTenant, IDicCapitalTenantService> {
	@Autowired
	private IDicCapitalTenantService dicCapitalTenantService;
	
	/**
	 * 分页列表查询
	 *
	 * @param dicCapitalTenant
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "首都租户-分页列表查询")
	@ApiOperation(value="首都租户-分页列表查询", notes="首都租户-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<DicCapitalTenant>> queryPageList(DicCapitalTenant dicCapitalTenant,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<DicCapitalTenant> queryWrapper = QueryGenerator.initQueryWrapper(dicCapitalTenant, req.getParameterMap());
		Page<DicCapitalTenant> page = new Page<DicCapitalTenant>(pageNo, pageSize);
		IPage<DicCapitalTenant> pageList = dicCapitalTenantService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param dicCapitalTenant
	 * @return
	 */
	@AutoLog(value = "首都租户-添加")
	@ApiOperation(value="首都租户-添加", notes="首都租户-添加")
	@RequiresPermissions("diccapitaltenant:dic_capital_tenant:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody DicCapitalTenant dicCapitalTenant) {
		dicCapitalTenantService.save(dicCapitalTenant);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param dicCapitalTenant
	 * @return
	 */
	@AutoLog(value = "首都租户-编辑")
	@ApiOperation(value="首都租户-编辑", notes="首都租户-编辑")
	@RequiresPermissions("diccapitaltenant:dic_capital_tenant:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody DicCapitalTenant dicCapitalTenant) {
		dicCapitalTenantService.updateById(dicCapitalTenant);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "首都租户-通过id删除")
	@ApiOperation(value="首都租户-通过id删除", notes="首都租户-通过id删除")
	@RequiresPermissions("diccapitaltenant:dic_capital_tenant:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		dicCapitalTenantService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "首都租户-批量删除")
	@ApiOperation(value="首都租户-批量删除", notes="首都租户-批量删除")
	@RequiresPermissions("diccapitaltenant:dic_capital_tenant:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.dicCapitalTenantService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "首都租户-通过id查询")
	@ApiOperation(value="首都租户-通过id查询", notes="首都租户-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<DicCapitalTenant> queryById(@RequestParam(name="id",required=true) String id) {
		DicCapitalTenant dicCapitalTenant = dicCapitalTenantService.getById(id);
		if(dicCapitalTenant==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(dicCapitalTenant);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param dicCapitalTenant
    */
    @RequiresPermissions("diccapitaltenant:dic_capital_tenant:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, DicCapitalTenant dicCapitalTenant) {
        return super.exportXls(request, dicCapitalTenant, DicCapitalTenant.class, "首都租户");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("diccapitaltenant:dic_capital_tenant:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, DicCapitalTenant.class);
    }

}
