package org.jeecg.modules.demo.dicnamepositionerr.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.dicnamepositionerr.entity.DicNamePositionErr;
import org.jeecg.modules.demo.dicnamepositionerr.service.IDicNamePositionErrService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 人名职务错误类型
 * @Author: jeecg-boot
 * @Date:   2023-11-08
 * @Version: V1.0
 */
@Api(tags="人名职务错误类型")
@RestController
@RequestMapping("/dicnamepositionerr/dicNamePositionErr")
@Slf4j
public class DicNamePositionErrController extends JeecgController<DicNamePositionErr, IDicNamePositionErrService> {
	@Autowired
	private IDicNamePositionErrService dicNamePositionErrService;
	
	/**
	 * 分页列表查询
	 *
	 * @param dicNamePositionErr
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "人名职务错误类型-分页列表查询")
	@ApiOperation(value="人名职务错误类型-分页列表查询", notes="人名职务错误类型-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<DicNamePositionErr>> queryPageList(DicNamePositionErr dicNamePositionErr,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<DicNamePositionErr> queryWrapper = QueryGenerator.initQueryWrapper(dicNamePositionErr, req.getParameterMap());
		Page<DicNamePositionErr> page = new Page<DicNamePositionErr>(pageNo, pageSize);
		IPage<DicNamePositionErr> pageList = dicNamePositionErrService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param dicNamePositionErr
	 * @return
	 */
	@AutoLog(value = "人名职务错误类型-添加")
	@ApiOperation(value="人名职务错误类型-添加", notes="人名职务错误类型-添加")
	@RequiresPermissions("dicnamepositionerr:dic_name_position_err:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody DicNamePositionErr dicNamePositionErr) {
		dicNamePositionErrService.save(dicNamePositionErr);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param dicNamePositionErr
	 * @return
	 */
	@AutoLog(value = "人名职务错误类型-编辑")
	@ApiOperation(value="人名职务错误类型-编辑", notes="人名职务错误类型-编辑")
	@RequiresPermissions("dicnamepositionerr:dic_name_position_err:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody DicNamePositionErr dicNamePositionErr) {
		dicNamePositionErrService.updateById(dicNamePositionErr);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "人名职务错误类型-通过id删除")
	@ApiOperation(value="人名职务错误类型-通过id删除", notes="人名职务错误类型-通过id删除")
	@RequiresPermissions("dicnamepositionerr:dic_name_position_err:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		dicNamePositionErrService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "人名职务错误类型-批量删除")
	@ApiOperation(value="人名职务错误类型-批量删除", notes="人名职务错误类型-批量删除")
	@RequiresPermissions("dicnamepositionerr:dic_name_position_err:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.dicNamePositionErrService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "人名职务错误类型-通过id查询")
	@ApiOperation(value="人名职务错误类型-通过id查询", notes="人名职务错误类型-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<DicNamePositionErr> queryById(@RequestParam(name="id",required=true) String id) {
		DicNamePositionErr dicNamePositionErr = dicNamePositionErrService.getById(id);
		if(dicNamePositionErr==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(dicNamePositionErr);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param dicNamePositionErr
    */
    @RequiresPermissions("dicnamepositionerr:dic_name_position_err:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, DicNamePositionErr dicNamePositionErr) {
        return super.exportXls(request, dicNamePositionErr, DicNamePositionErr.class, "人名职务错误类型");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("dicnamepositionerr:dic_name_position_err:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, DicNamePositionErr.class);
    }

}
