package org.jeecg.modules.demo.linkanchorlist.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.linkanchorlist.entity.LinkAnchorList;
import org.jeecg.modules.demo.linkanchorlist.service.ILinkAnchorListService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 锚链接表
 * @Author: jeecg-boot
 * @Date:   2023-06-02
 * @Version: V1.0
 */
@Api(tags="锚链接表")
@RestController
@RequestMapping("/linkanchorlist/linkAnchorList")
@Slf4j
public class LinkAnchorListController extends JeecgController<LinkAnchorList, ILinkAnchorListService> {
	@Autowired
	private ILinkAnchorListService linkAnchorListService;
	
	/**
	 * 分页列表查询
	 *
	 * @param linkAnchorList
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "锚链接表-分页列表查询")
	@ApiOperation(value="锚链接表-分页列表查询", notes="锚链接表-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<LinkAnchorList>> queryPageList(LinkAnchorList linkAnchorList,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<LinkAnchorList> queryWrapper = QueryGenerator.initQueryWrapper(linkAnchorList, req.getParameterMap());
		Page<LinkAnchorList> page = new Page<LinkAnchorList>(pageNo, pageSize);
		IPage<LinkAnchorList> pageList = linkAnchorListService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param linkAnchorList
	 * @return
	 */
	@AutoLog(value = "锚链接表-添加")
	@ApiOperation(value="锚链接表-添加", notes="锚链接表-添加")
	@RequiresPermissions("linkanchorlist:link_anchor_list:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody LinkAnchorList linkAnchorList) {
		linkAnchorListService.save(linkAnchorList);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param linkAnchorList
	 * @return
	 */
	@AutoLog(value = "锚链接表-编辑")
	@ApiOperation(value="锚链接表-编辑", notes="锚链接表-编辑")
	@RequiresPermissions("linkanchorlist:link_anchor_list:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody LinkAnchorList linkAnchorList) {
		linkAnchorListService.updateById(linkAnchorList);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "锚链接表-通过id删除")
	@ApiOperation(value="锚链接表-通过id删除", notes="锚链接表-通过id删除")
	@RequiresPermissions("linkanchorlist:link_anchor_list:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		linkAnchorListService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "锚链接表-批量删除")
	@ApiOperation(value="锚链接表-批量删除", notes="锚链接表-批量删除")
	@RequiresPermissions("linkanchorlist:link_anchor_list:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.linkAnchorListService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "锚链接表-通过id查询")
	@ApiOperation(value="锚链接表-通过id查询", notes="锚链接表-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<LinkAnchorList> queryById(@RequestParam(name="id",required=true) String id) {
		LinkAnchorList linkAnchorList = linkAnchorListService.getById(id);
		if(linkAnchorList==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(linkAnchorList);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param linkAnchorList
    */
    @RequiresPermissions("linkanchorlist:link_anchor_list:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, LinkAnchorList linkAnchorList) {
        return super.exportXls(request, linkAnchorList, LinkAnchorList.class, "锚链接表");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("linkanchorlist:link_anchor_list:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, LinkAnchorList.class);
    }

}
