package org.jeecg.modules.demo.linkcaptureerrorlog.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.linkcaptureerrorlog.entity.LinkCaptureErrorLog;
import org.jeecg.modules.demo.linkcaptureerrorlog.service.ILinkCaptureErrorLogService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 错敏词日志信息
 * @Author: jeecg-boot
 * @Date:   2023-04-17
 * @Version: V1.0
 */
@Api(tags="错敏词日志信息")
@RestController
@RequestMapping("/linkcaptureerrorlog/linkCaptureErrorLog")
@Slf4j
public class LinkCaptureErrorLogController extends JeecgController<LinkCaptureErrorLog, ILinkCaptureErrorLogService> {
	@Autowired
	private ILinkCaptureErrorLogService linkCaptureErrorLogService;
	
	/**
	 * 分页列表查询
	 *
	 * @param linkCaptureErrorLog
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "错敏词日志信息-分页列表查询")
	@ApiOperation(value="错敏词日志信息-分页列表查询", notes="错敏词日志信息-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<LinkCaptureErrorLog>> queryPageList(LinkCaptureErrorLog linkCaptureErrorLog,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<LinkCaptureErrorLog> queryWrapper = QueryGenerator.initQueryWrapper(linkCaptureErrorLog, req.getParameterMap());
		Page<LinkCaptureErrorLog> page = new Page<LinkCaptureErrorLog>(pageNo, pageSize);
		IPage<LinkCaptureErrorLog> pageList = linkCaptureErrorLogService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param linkCaptureErrorLog
	 * @return
	 */
	@AutoLog(value = "错敏词日志信息-添加")
	@ApiOperation(value="错敏词日志信息-添加", notes="错敏词日志信息-添加")
	@RequiresPermissions("linkcaptureerrorlog:link_capture_error_log:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody LinkCaptureErrorLog linkCaptureErrorLog) {
		linkCaptureErrorLogService.save(linkCaptureErrorLog);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param linkCaptureErrorLog
	 * @return
	 */
	@AutoLog(value = "错敏词日志信息-编辑")
	@ApiOperation(value="错敏词日志信息-编辑", notes="错敏词日志信息-编辑")
	@RequiresPermissions("linkcaptureerrorlog:link_capture_error_log:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody LinkCaptureErrorLog linkCaptureErrorLog) {
		linkCaptureErrorLogService.updateById(linkCaptureErrorLog);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "错敏词日志信息-通过id删除")
	@ApiOperation(value="错敏词日志信息-通过id删除", notes="错敏词日志信息-通过id删除")
	@RequiresPermissions("linkcaptureerrorlog:link_capture_error_log:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		linkCaptureErrorLogService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "错敏词日志信息-批量删除")
	@ApiOperation(value="错敏词日志信息-批量删除", notes="错敏词日志信息-批量删除")
	@RequiresPermissions("linkcaptureerrorlog:link_capture_error_log:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.linkCaptureErrorLogService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "错敏词日志信息-通过id查询")
	@ApiOperation(value="错敏词日志信息-通过id查询", notes="错敏词日志信息-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<LinkCaptureErrorLog> queryById(@RequestParam(name="id",required=true) String id) {
		LinkCaptureErrorLog linkCaptureErrorLog = linkCaptureErrorLogService.getById(id);
		if(linkCaptureErrorLog==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(linkCaptureErrorLog);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param linkCaptureErrorLog
    */
    @RequiresPermissions("linkcaptureerrorlog:link_capture_error_log:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, LinkCaptureErrorLog linkCaptureErrorLog) {
        return super.exportXls(request, linkCaptureErrorLog, LinkCaptureErrorLog.class, "错敏词日志信息");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("linkcaptureerrorlog:link_capture_error_log:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, LinkCaptureErrorLog.class);
    }

}
