package org.jeecg.modules.demo.linkpersonalbankcarddetectionstatistics.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.linkpersonalbankcarddetectionstatistics.entity.LinkPersonalBankCardDetectionStatistics;
import org.jeecg.modules.demo.linkpersonalbankcarddetectionstatistics.service.ILinkPersonalBankCardDetectionStatisticsService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 银行卡统计信息
 * @Author: jeecg-boot
 * @Date:   2023-05-31
 * @Version: V1.0
 */
@Api(tags="银行卡统计信息")
@RestController
@RequestMapping("/linkpersonalbankcarddetectionstatistics/linkPersonalBankCardDetectionStatistics")
@Slf4j
public class LinkPersonalBankCardDetectionStatisticsController extends JeecgController<LinkPersonalBankCardDetectionStatistics, ILinkPersonalBankCardDetectionStatisticsService> {
	@Autowired
	private ILinkPersonalBankCardDetectionStatisticsService linkPersonalBankCardDetectionStatisticsService;
	
	/**
	 * 分页列表查询
	 *
	 * @param linkPersonalBankCardDetectionStatistics
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "银行卡统计信息-分页列表查询")
	@ApiOperation(value="银行卡统计信息-分页列表查询", notes="银行卡统计信息-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<LinkPersonalBankCardDetectionStatistics>> queryPageList(LinkPersonalBankCardDetectionStatistics linkPersonalBankCardDetectionStatistics,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<LinkPersonalBankCardDetectionStatistics> queryWrapper = QueryGenerator.initQueryWrapper(linkPersonalBankCardDetectionStatistics, req.getParameterMap());
		Page<LinkPersonalBankCardDetectionStatistics> page = new Page<LinkPersonalBankCardDetectionStatistics>(pageNo, pageSize);
		IPage<LinkPersonalBankCardDetectionStatistics> pageList = linkPersonalBankCardDetectionStatisticsService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param linkPersonalBankCardDetectionStatistics
	 * @return
	 */
	@AutoLog(value = "银行卡统计信息-添加")
	@ApiOperation(value="银行卡统计信息-添加", notes="银行卡统计信息-添加")
	@RequiresPermissions("linkpersonalbankcarddetectionstatistics:link_personal_bank_card_detection_statistics:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody LinkPersonalBankCardDetectionStatistics linkPersonalBankCardDetectionStatistics) {
		linkPersonalBankCardDetectionStatisticsService.save(linkPersonalBankCardDetectionStatistics);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param linkPersonalBankCardDetectionStatistics
	 * @return
	 */
	@AutoLog(value = "银行卡统计信息-编辑")
	@ApiOperation(value="银行卡统计信息-编辑", notes="银行卡统计信息-编辑")
	@RequiresPermissions("linkpersonalbankcarddetectionstatistics:link_personal_bank_card_detection_statistics:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody LinkPersonalBankCardDetectionStatistics linkPersonalBankCardDetectionStatistics) {
		linkPersonalBankCardDetectionStatisticsService.updateById(linkPersonalBankCardDetectionStatistics);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "银行卡统计信息-通过id删除")
	@ApiOperation(value="银行卡统计信息-通过id删除", notes="银行卡统计信息-通过id删除")
	@RequiresPermissions("linkpersonalbankcarddetectionstatistics:link_personal_bank_card_detection_statistics:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		linkPersonalBankCardDetectionStatisticsService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "银行卡统计信息-批量删除")
	@ApiOperation(value="银行卡统计信息-批量删除", notes="银行卡统计信息-批量删除")
	@RequiresPermissions("linkpersonalbankcarddetectionstatistics:link_personal_bank_card_detection_statistics:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.linkPersonalBankCardDetectionStatisticsService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "银行卡统计信息-通过id查询")
	@ApiOperation(value="银行卡统计信息-通过id查询", notes="银行卡统计信息-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<LinkPersonalBankCardDetectionStatistics> queryById(@RequestParam(name="id",required=true) String id) {
		LinkPersonalBankCardDetectionStatistics linkPersonalBankCardDetectionStatistics = linkPersonalBankCardDetectionStatisticsService.getById(id);
		if(linkPersonalBankCardDetectionStatistics==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(linkPersonalBankCardDetectionStatistics);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param linkPersonalBankCardDetectionStatistics
    */
    @RequiresPermissions("linkpersonalbankcarddetectionstatistics:link_personal_bank_card_detection_statistics:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, LinkPersonalBankCardDetectionStatistics linkPersonalBankCardDetectionStatistics) {
        return super.exportXls(request, linkPersonalBankCardDetectionStatistics, LinkPersonalBankCardDetectionStatistics.class, "银行卡统计信息");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("linkpersonalbankcarddetectionstatistics:link_personal_bank_card_detection_statistics:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, LinkPersonalBankCardDetectionStatistics.class);
    }

}
