package org.jeecg.modules.demo.linkpersonalphonewhitelist.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.linkpersonalphonewhitelist.entity.LinkPersonalPhoneWhiteList;
import org.jeecg.modules.demo.linkpersonalphonewhitelist.service.ILinkPersonalPhoneWhiteListService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 个人信息手机号白名单
 * @Author: jeecg-boot
 * @Date:   2023-05-24
 * @Version: V1.0
 */
@Api(tags="个人信息手机号白名单")
@RestController
@RequestMapping("/linkpersonalphonewhitelist/linkPersonalPhoneWhiteList")
@Slf4j
public class LinkPersonalPhoneWhiteListController extends JeecgController<LinkPersonalPhoneWhiteList, ILinkPersonalPhoneWhiteListService> {
	@Autowired
	private ILinkPersonalPhoneWhiteListService linkPersonalPhoneWhiteListService;
	
	/**
	 * 分页列表查询
	 *
	 * @param linkPersonalPhoneWhiteList
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "个人信息手机号白名单-分页列表查询")
	@ApiOperation(value="个人信息手机号白名单-分页列表查询", notes="个人信息手机号白名单-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<LinkPersonalPhoneWhiteList>> queryPageList(LinkPersonalPhoneWhiteList linkPersonalPhoneWhiteList,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<LinkPersonalPhoneWhiteList> queryWrapper = QueryGenerator.initQueryWrapper(linkPersonalPhoneWhiteList, req.getParameterMap());
		Page<LinkPersonalPhoneWhiteList> page = new Page<LinkPersonalPhoneWhiteList>(pageNo, pageSize);
		IPage<LinkPersonalPhoneWhiteList> pageList = linkPersonalPhoneWhiteListService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param linkPersonalPhoneWhiteList
	 * @return
	 */
	@AutoLog(value = "个人信息手机号白名单-添加")
	@ApiOperation(value="个人信息手机号白名单-添加", notes="个人信息手机号白名单-添加")
	@RequiresPermissions("linkpersonalphonewhitelist:link_personal_phone_white_list:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody LinkPersonalPhoneWhiteList linkPersonalPhoneWhiteList) {
		linkPersonalPhoneWhiteListService.save(linkPersonalPhoneWhiteList);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param linkPersonalPhoneWhiteList
	 * @return
	 */
	@AutoLog(value = "个人信息手机号白名单-编辑")
	@ApiOperation(value="个人信息手机号白名单-编辑", notes="个人信息手机号白名单-编辑")
	@RequiresPermissions("linkpersonalphonewhitelist:link_personal_phone_white_list:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody LinkPersonalPhoneWhiteList linkPersonalPhoneWhiteList) {
		linkPersonalPhoneWhiteListService.updateById(linkPersonalPhoneWhiteList);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "个人信息手机号白名单-通过id删除")
	@ApiOperation(value="个人信息手机号白名单-通过id删除", notes="个人信息手机号白名单-通过id删除")
	@RequiresPermissions("linkpersonalphonewhitelist:link_personal_phone_white_list:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		linkPersonalPhoneWhiteListService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "个人信息手机号白名单-批量删除")
	@ApiOperation(value="个人信息手机号白名单-批量删除", notes="个人信息手机号白名单-批量删除")
	@RequiresPermissions("linkpersonalphonewhitelist:link_personal_phone_white_list:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.linkPersonalPhoneWhiteListService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "个人信息手机号白名单-通过id查询")
	@ApiOperation(value="个人信息手机号白名单-通过id查询", notes="个人信息手机号白名单-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<LinkPersonalPhoneWhiteList> queryById(@RequestParam(name="id",required=true) String id) {
		LinkPersonalPhoneWhiteList linkPersonalPhoneWhiteList = linkPersonalPhoneWhiteListService.getById(id);
		if(linkPersonalPhoneWhiteList==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(linkPersonalPhoneWhiteList);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param linkPersonalPhoneWhiteList
    */
    @RequiresPermissions("linkpersonalphonewhitelist:link_personal_phone_white_list:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, LinkPersonalPhoneWhiteList linkPersonalPhoneWhiteList) {
        return super.exportXls(request, linkPersonalPhoneWhiteList, LinkPersonalPhoneWhiteList.class, "个人信息手机号白名单");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("linkpersonalphonewhitelist:link_personal_phone_white_list:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, LinkPersonalPhoneWhiteList.class);
    }

}
