package org.jeecg.modules.demo.linkpublishingtimegrasping.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.linkpublishingtimegrasping.entity.LinkPublishingTimeGrasping;
import org.jeecg.modules.demo.linkpublishingtimegrasping.service.ILinkPublishingTimeGraspingService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.modules.demo.mainsite.entity.MainSite;
import org.jeecg.modules.demo.mainsite.service.IMainSiteService;
import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 发布时间元素抓取定位
 * @Author: jeecg-boot
 * @Date:   2023-04-13
 * @Version: V1.0
 */
@Api(tags="发布时间元素抓取定位")
@RestController
@RequestMapping("/linkpublishingtimegrasping/linkPublishingTimeGrasping")
@Slf4j
public class LinkPublishingTimeGraspingController extends JeecgController<LinkPublishingTimeGrasping, ILinkPublishingTimeGraspingService> {
	@Autowired
	private ILinkPublishingTimeGraspingService linkPublishingTimeGraspingService;
	 @Autowired
	 private IMainSiteService iMainSiteService;
	/**
	 * 分页列表查询
	 *
	 * @param linkPublishingTimeGrasping
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "发布时间元素抓取定位-分页列表查询")
	@ApiOperation(value="发布时间元素抓取定位-分页列表查询", notes="发布时间元素抓取定位-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<LinkPublishingTimeGrasping>> queryPageList(LinkPublishingTimeGrasping linkPublishingTimeGrasping,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<LinkPublishingTimeGrasping> queryWrapper = QueryGenerator.initQueryWrapper(linkPublishingTimeGrasping, req.getParameterMap());
		Page<LinkPublishingTimeGrasping> page = new Page<LinkPublishingTimeGrasping>(pageNo, pageSize);
		IPage<LinkPublishingTimeGrasping> pageList = linkPublishingTimeGraspingService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param linkPublishingTimeGrasping
	 * @return
	 */
	@AutoLog(value = "发布时间元素抓取定位-添加")
	@ApiOperation(value="发布时间元素抓取定位-添加", notes="发布时间元素抓取定位-添加")
	@RequiresPermissions("linkpublishingtimegrasping:link_publishing_time_grasping:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody LinkPublishingTimeGrasping linkPublishingTimeGrasping) {
		try {
			String mainSiteId = linkPublishingTimeGrasping.getMainSiteId();
			MainSite mainSite = iMainSiteService.getById(mainSiteId);
			linkPublishingTimeGrasping.setMainSiteName(mainSite.getMainSiteName());
			linkPublishingTimeGrasping.setMainSiteUrl(mainSite.getMainSiteUrl());
		}catch (Exception e){
			e.printStackTrace();
		}
		linkPublishingTimeGraspingService.save(linkPublishingTimeGrasping);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param linkPublishingTimeGrasping
	 * @return
	 */
	@AutoLog(value = "发布时间元素抓取定位-编辑")
	@ApiOperation(value="发布时间元素抓取定位-编辑", notes="发布时间元素抓取定位-编辑")
	@RequiresPermissions("linkpublishingtimegrasping:link_publishing_time_grasping:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody LinkPublishingTimeGrasping linkPublishingTimeGrasping) {
		try {
			String mainSiteId = linkPublishingTimeGrasping.getMainSiteId();
			MainSite mainSite = iMainSiteService.getById(mainSiteId);
			linkPublishingTimeGrasping.setMainSiteName(mainSite.getMainSiteName());
			linkPublishingTimeGrasping.setMainSiteUrl(mainSite.getMainSiteUrl());
		}catch (Exception e){
			e.printStackTrace();
		}
		linkPublishingTimeGraspingService.updateById(linkPublishingTimeGrasping);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "发布时间元素抓取定位-通过id删除")
	@ApiOperation(value="发布时间元素抓取定位-通过id删除", notes="发布时间元素抓取定位-通过id删除")
	@RequiresPermissions("linkpublishingtimegrasping:link_publishing_time_grasping:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		linkPublishingTimeGraspingService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "发布时间元素抓取定位-批量删除")
	@ApiOperation(value="发布时间元素抓取定位-批量删除", notes="发布时间元素抓取定位-批量删除")
	@RequiresPermissions("linkpublishingtimegrasping:link_publishing_time_grasping:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.linkPublishingTimeGraspingService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "发布时间元素抓取定位-通过id查询")
	@ApiOperation(value="发布时间元素抓取定位-通过id查询", notes="发布时间元素抓取定位-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<LinkPublishingTimeGrasping> queryById(@RequestParam(name="id",required=true) String id) {
		LinkPublishingTimeGrasping linkPublishingTimeGrasping = linkPublishingTimeGraspingService.getById(id);
		if(linkPublishingTimeGrasping==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(linkPublishingTimeGrasping);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param linkPublishingTimeGrasping
    */
    @RequiresPermissions("linkpublishingtimegrasping:link_publishing_time_grasping:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, LinkPublishingTimeGrasping linkPublishingTimeGrasping) {
        return super.exportXls(request, linkPublishingTimeGrasping, LinkPublishingTimeGrasping.class, "发布时间元素抓取定位");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("linkpublishingtimegrasping:link_publishing_time_grasping:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, LinkPublishingTimeGrasping.class);
    }

}
