package org.jeecg.modules.demo.linkwechatidnumberdetectionlog.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.linkwechatidnumberdetectionlog.entity.LinkWechatIdNumberDetectionLog;
import org.jeecg.modules.demo.linkwechatidnumberdetectionlog.service.ILinkWechatIdNumberDetectionLogService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 微信身份证号检测日志
 * @Author: jeecg-boot
 * @Date:   2023-07-03
 * @Version: V1.0
 */
@Api(tags="微信身份证号检测日志")
@RestController
@RequestMapping("/linkwechatidnumberdetectionlog/linkWechatIdNumberDetectionLog")
@Slf4j
public class LinkWechatIdNumberDetectionLogController extends JeecgController<LinkWechatIdNumberDetectionLog, ILinkWechatIdNumberDetectionLogService> {
	@Autowired
	private ILinkWechatIdNumberDetectionLogService linkWechatIdNumberDetectionLogService;
	
	/**
	 * 分页列表查询
	 *
	 * @param linkWechatIdNumberDetectionLog
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "微信身份证号检测日志-分页列表查询")
	@ApiOperation(value="微信身份证号检测日志-分页列表查询", notes="微信身份证号检测日志-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<LinkWechatIdNumberDetectionLog>> queryPageList(LinkWechatIdNumberDetectionLog linkWechatIdNumberDetectionLog,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<LinkWechatIdNumberDetectionLog> queryWrapper = QueryGenerator.initQueryWrapper(linkWechatIdNumberDetectionLog, req.getParameterMap());
		Page<LinkWechatIdNumberDetectionLog> page = new Page<LinkWechatIdNumberDetectionLog>(pageNo, pageSize);
		IPage<LinkWechatIdNumberDetectionLog> pageList = linkWechatIdNumberDetectionLogService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param linkWechatIdNumberDetectionLog
	 * @return
	 */
	@AutoLog(value = "微信身份证号检测日志-添加")
	@ApiOperation(value="微信身份证号检测日志-添加", notes="微信身份证号检测日志-添加")
	@RequiresPermissions("linkwechatidnumberdetectionlog:link_wechat_id_number_detection_log:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody LinkWechatIdNumberDetectionLog linkWechatIdNumberDetectionLog) {
		linkWechatIdNumberDetectionLogService.save(linkWechatIdNumberDetectionLog);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param linkWechatIdNumberDetectionLog
	 * @return
	 */
	@AutoLog(value = "微信身份证号检测日志-编辑")
	@ApiOperation(value="微信身份证号检测日志-编辑", notes="微信身份证号检测日志-编辑")
	@RequiresPermissions("linkwechatidnumberdetectionlog:link_wechat_id_number_detection_log:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody LinkWechatIdNumberDetectionLog linkWechatIdNumberDetectionLog) {
		linkWechatIdNumberDetectionLogService.updateById(linkWechatIdNumberDetectionLog);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "微信身份证号检测日志-通过id删除")
	@ApiOperation(value="微信身份证号检测日志-通过id删除", notes="微信身份证号检测日志-通过id删除")
	@RequiresPermissions("linkwechatidnumberdetectionlog:link_wechat_id_number_detection_log:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		linkWechatIdNumberDetectionLogService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "微信身份证号检测日志-批量删除")
	@ApiOperation(value="微信身份证号检测日志-批量删除", notes="微信身份证号检测日志-批量删除")
	@RequiresPermissions("linkwechatidnumberdetectionlog:link_wechat_id_number_detection_log:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.linkWechatIdNumberDetectionLogService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "微信身份证号检测日志-通过id查询")
	@ApiOperation(value="微信身份证号检测日志-通过id查询", notes="微信身份证号检测日志-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<LinkWechatIdNumberDetectionLog> queryById(@RequestParam(name="id",required=true) String id) {
		LinkWechatIdNumberDetectionLog linkWechatIdNumberDetectionLog = linkWechatIdNumberDetectionLogService.getById(id);
		if(linkWechatIdNumberDetectionLog==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(linkWechatIdNumberDetectionLog);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param linkWechatIdNumberDetectionLog
    */
    @RequiresPermissions("linkwechatidnumberdetectionlog:link_wechat_id_number_detection_log:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, LinkWechatIdNumberDetectionLog linkWechatIdNumberDetectionLog) {
        return super.exportXls(request, linkWechatIdNumberDetectionLog, LinkWechatIdNumberDetectionLog.class, "微信身份证号检测日志");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("linkwechatidnumberdetectionlog:link_wechat_id_number_detection_log:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, LinkWechatIdNumberDetectionLog.class);
    }

}
