package org.jeecg.modules.demo.linkwechatphonewhitelist.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.linkwechatphonewhitelist.entity.LinkWechatPhoneWhiteList;
import org.jeecg.modules.demo.linkwechatphonewhitelist.service.ILinkWechatPhoneWhiteListService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 微信电话白名单
 * @Author: jeecg-boot
 * @Date:   2023-07-27
 * @Version: V1.0
 */
@Api(tags="微信电话白名单")
@RestController
@RequestMapping("/linkwechatphonewhitelist/linkWechatPhoneWhiteList")
@Slf4j
public class LinkWechatPhoneWhiteListController extends JeecgController<LinkWechatPhoneWhiteList, ILinkWechatPhoneWhiteListService> {
	@Autowired
	private ILinkWechatPhoneWhiteListService linkWechatPhoneWhiteListService;
	
	/**
	 * 分页列表查询
	 *
	 * @param linkWechatPhoneWhiteList
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "微信电话白名单-分页列表查询")
	@ApiOperation(value="微信电话白名单-分页列表查询", notes="微信电话白名单-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<LinkWechatPhoneWhiteList>> queryPageList(LinkWechatPhoneWhiteList linkWechatPhoneWhiteList,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<LinkWechatPhoneWhiteList> queryWrapper = QueryGenerator.initQueryWrapper(linkWechatPhoneWhiteList, req.getParameterMap());
		Page<LinkWechatPhoneWhiteList> page = new Page<LinkWechatPhoneWhiteList>(pageNo, pageSize);
		IPage<LinkWechatPhoneWhiteList> pageList = linkWechatPhoneWhiteListService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param linkWechatPhoneWhiteList
	 * @return
	 */
	@AutoLog(value = "微信电话白名单-添加")
	@ApiOperation(value="微信电话白名单-添加", notes="微信电话白名单-添加")
	@RequiresPermissions("linkwechatphonewhitelist:link_wechat_phone_white_list:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody LinkWechatPhoneWhiteList linkWechatPhoneWhiteList) {
		linkWechatPhoneWhiteListService.save(linkWechatPhoneWhiteList);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param linkWechatPhoneWhiteList
	 * @return
	 */
	@AutoLog(value = "微信电话白名单-编辑")
	@ApiOperation(value="微信电话白名单-编辑", notes="微信电话白名单-编辑")
	@RequiresPermissions("linkwechatphonewhitelist:link_wechat_phone_white_list:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody LinkWechatPhoneWhiteList linkWechatPhoneWhiteList) {
		linkWechatPhoneWhiteListService.updateById(linkWechatPhoneWhiteList);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "微信电话白名单-通过id删除")
	@ApiOperation(value="微信电话白名单-通过id删除", notes="微信电话白名单-通过id删除")
	@RequiresPermissions("linkwechatphonewhitelist:link_wechat_phone_white_list:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		linkWechatPhoneWhiteListService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "微信电话白名单-批量删除")
	@ApiOperation(value="微信电话白名单-批量删除", notes="微信电话白名单-批量删除")
	@RequiresPermissions("linkwechatphonewhitelist:link_wechat_phone_white_list:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.linkWechatPhoneWhiteListService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "微信电话白名单-通过id查询")
	@ApiOperation(value="微信电话白名单-通过id查询", notes="微信电话白名单-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<LinkWechatPhoneWhiteList> queryById(@RequestParam(name="id",required=true) String id) {
		LinkWechatPhoneWhiteList linkWechatPhoneWhiteList = linkWechatPhoneWhiteListService.getById(id);
		if(linkWechatPhoneWhiteList==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(linkWechatPhoneWhiteList);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param linkWechatPhoneWhiteList
    */
    @RequiresPermissions("linkwechatphonewhitelist:link_wechat_phone_white_list:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, LinkWechatPhoneWhiteList linkWechatPhoneWhiteList) {
        return super.exportXls(request, linkWechatPhoneWhiteList, LinkWechatPhoneWhiteList.class, "微信电话白名单");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("linkwechatphonewhitelist:link_wechat_phone_white_list:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, LinkWechatPhoneWhiteList.class);
    }

}
