package org.jeecg.modules.demo.linkweibobankcardwhitelist.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.linkweibobankcardwhitelist.entity.LinkWeiboBankCardWhiteList;
import org.jeecg.modules.demo.linkweibobankcardwhitelist.service.ILinkWeiboBankCardWhiteListService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 微博银行卡白名单
 * @Author: jeecg-boot
 * @Date:   2023-07-27
 * @Version: V1.0
 */
@Api(tags="微博银行卡白名单")
@RestController
@RequestMapping("/linkweibobankcardwhitelist/linkWeiboBankCardWhiteList")
@Slf4j
public class LinkWeiboBankCardWhiteListController extends JeecgController<LinkWeiboBankCardWhiteList, ILinkWeiboBankCardWhiteListService> {
	@Autowired
	private ILinkWeiboBankCardWhiteListService linkWeiboBankCardWhiteListService;
	
	/**
	 * 分页列表查询
	 *
	 * @param linkWeiboBankCardWhiteList
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "微博银行卡白名单-分页列表查询")
	@ApiOperation(value="微博银行卡白名单-分页列表查询", notes="微博银行卡白名单-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<LinkWeiboBankCardWhiteList>> queryPageList(LinkWeiboBankCardWhiteList linkWeiboBankCardWhiteList,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<LinkWeiboBankCardWhiteList> queryWrapper = QueryGenerator.initQueryWrapper(linkWeiboBankCardWhiteList, req.getParameterMap());
		Page<LinkWeiboBankCardWhiteList> page = new Page<LinkWeiboBankCardWhiteList>(pageNo, pageSize);
		IPage<LinkWeiboBankCardWhiteList> pageList = linkWeiboBankCardWhiteListService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param linkWeiboBankCardWhiteList
	 * @return
	 */
	@AutoLog(value = "微博银行卡白名单-添加")
	@ApiOperation(value="微博银行卡白名单-添加", notes="微博银行卡白名单-添加")
	@RequiresPermissions("linkweibobankcardwhitelist:link_weibo_bank_card_white_list:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody LinkWeiboBankCardWhiteList linkWeiboBankCardWhiteList) {
		linkWeiboBankCardWhiteListService.save(linkWeiboBankCardWhiteList);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param linkWeiboBankCardWhiteList
	 * @return
	 */
	@AutoLog(value = "微博银行卡白名单-编辑")
	@ApiOperation(value="微博银行卡白名单-编辑", notes="微博银行卡白名单-编辑")
	@RequiresPermissions("linkweibobankcardwhitelist:link_weibo_bank_card_white_list:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody LinkWeiboBankCardWhiteList linkWeiboBankCardWhiteList) {
		linkWeiboBankCardWhiteListService.updateById(linkWeiboBankCardWhiteList);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "微博银行卡白名单-通过id删除")
	@ApiOperation(value="微博银行卡白名单-通过id删除", notes="微博银行卡白名单-通过id删除")
	@RequiresPermissions("linkweibobankcardwhitelist:link_weibo_bank_card_white_list:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		linkWeiboBankCardWhiteListService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "微博银行卡白名单-批量删除")
	@ApiOperation(value="微博银行卡白名单-批量删除", notes="微博银行卡白名单-批量删除")
	@RequiresPermissions("linkweibobankcardwhitelist:link_weibo_bank_card_white_list:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.linkWeiboBankCardWhiteListService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "微博银行卡白名单-通过id查询")
	@ApiOperation(value="微博银行卡白名单-通过id查询", notes="微博银行卡白名单-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<LinkWeiboBankCardWhiteList> queryById(@RequestParam(name="id",required=true) String id) {
		LinkWeiboBankCardWhiteList linkWeiboBankCardWhiteList = linkWeiboBankCardWhiteListService.getById(id);
		if(linkWeiboBankCardWhiteList==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(linkWeiboBankCardWhiteList);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param linkWeiboBankCardWhiteList
    */
    @RequiresPermissions("linkweibobankcardwhitelist:link_weibo_bank_card_white_list:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, LinkWeiboBankCardWhiteList linkWeiboBankCardWhiteList) {
        return super.exportXls(request, linkWeiboBankCardWhiteList, LinkWeiboBankCardWhiteList.class, "微博银行卡白名单");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("linkweibobankcardwhitelist:link_weibo_bank_card_white_list:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, LinkWeiboBankCardWhiteList.class);
    }

}
