package org.jeecg.modules.demo.linkweibophonedetectionlog.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.linkweibophonedetectionlog.entity.LinkWeiboPhoneDetectionLog;
import org.jeecg.modules.demo.linkweibophonedetectionlog.entity.LinkWeiboPhoneDetectionLogVo;
import org.jeecg.modules.demo.linkweibophonedetectionlog.service.ILinkWeiboPhoneDetectionLogService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.modules.demo.linkweibophonedetectionlog.service.ILinkWeiboPhoneDetectionLogVoService;
import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 微博手机号检测日志
 * @Author: jeecg-boot
 * @Date:   2023-07-03
 * @Version: V1.0
 */
@Api(tags="微博手机号检测日志")
@RestController
@RequestMapping("/linkweibophonedetectionlog/linkWeiboPhoneDetectionLog")
@Slf4j
public class LinkWeiboPhoneDetectionLogController extends JeecgController<LinkWeiboPhoneDetectionLog, ILinkWeiboPhoneDetectionLogService> {
	@Autowired
	private ILinkWeiboPhoneDetectionLogService linkWeiboPhoneDetectionLogService;

	@Autowired
	private ILinkWeiboPhoneDetectionLogVoService iLinkWeiboPhoneDetectionLogVoService;
	
	/**
	 * 分页列表查询
	 *
	 * @param linkWeiboPhoneDetectionLog
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "微博手机号检测日志-分页列表查询")
	@ApiOperation(value="微博手机号检测日志-分页列表查询", notes="微博手机号检测日志-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<LinkWeiboPhoneDetectionLog>> queryPageList(LinkWeiboPhoneDetectionLog linkWeiboPhoneDetectionLog,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<LinkWeiboPhoneDetectionLog> queryWrapper = QueryGenerator.initQueryWrapper(linkWeiboPhoneDetectionLog, req.getParameterMap());
		Page<LinkWeiboPhoneDetectionLog> page = new Page<LinkWeiboPhoneDetectionLog>(pageNo, pageSize);
		IPage<LinkWeiboPhoneDetectionLog> pageList = linkWeiboPhoneDetectionLogService.page(page, queryWrapper);
		return Result.OK(pageList);
	}

	 @ApiOperation(value="微博手机号检测日志-分页列表查询", notes="微博手机号检测日志-分页列表查询")
	 @GetMapping(value = "/listVo")
	 public Result<IPage<LinkWeiboPhoneDetectionLogVo>> queryPageListVo(LinkWeiboPhoneDetectionLogVo linkWeiboPhoneDetectionLogVo,
																		@RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
																		@RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
																		HttpServletRequest req) {
		 QueryWrapper<LinkWeiboPhoneDetectionLogVo> queryWrapper = QueryGenerator.initQueryWrapper(linkWeiboPhoneDetectionLogVo, req.getParameterMap());
		 Page<LinkWeiboPhoneDetectionLogVo> page = new Page<LinkWeiboPhoneDetectionLogVo>(pageNo, pageSize);
		 IPage<LinkWeiboPhoneDetectionLogVo> pageList = iLinkWeiboPhoneDetectionLogVoService.page(page, queryWrapper);
		 return Result.OK(pageList);
	 }
	/**
	 *   添加
	 *
	 * @param linkWeiboPhoneDetectionLog
	 * @return
	 */
	@AutoLog(value = "微博手机号检测日志-添加")
	@ApiOperation(value="微博手机号检测日志-添加", notes="微博手机号检测日志-添加")
	@RequiresPermissions("linkweibophonedetectionlog:link_weibo_phone_detection_log:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody LinkWeiboPhoneDetectionLog linkWeiboPhoneDetectionLog) {
		linkWeiboPhoneDetectionLogService.save(linkWeiboPhoneDetectionLog);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param linkWeiboPhoneDetectionLog
	 * @return
	 */
	@AutoLog(value = "微博手机号检测日志-编辑")
	@ApiOperation(value="微博手机号检测日志-编辑", notes="微博手机号检测日志-编辑")
	@RequiresPermissions("linkweibophonedetectionlog:link_weibo_phone_detection_log:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody LinkWeiboPhoneDetectionLog linkWeiboPhoneDetectionLog) {
		linkWeiboPhoneDetectionLogService.updateById(linkWeiboPhoneDetectionLog);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "微博手机号检测日志-通过id删除")
	@ApiOperation(value="微博手机号检测日志-通过id删除", notes="微博手机号检测日志-通过id删除")
	@RequiresPermissions("linkweibophonedetectionlog:link_weibo_phone_detection_log:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		linkWeiboPhoneDetectionLogService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "微博手机号检测日志-批量删除")
	@ApiOperation(value="微博手机号检测日志-批量删除", notes="微博手机号检测日志-批量删除")
	@RequiresPermissions("linkweibophonedetectionlog:link_weibo_phone_detection_log:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.linkWeiboPhoneDetectionLogService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "微博手机号检测日志-通过id查询")
	@ApiOperation(value="微博手机号检测日志-通过id查询", notes="微博手机号检测日志-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<LinkWeiboPhoneDetectionLog> queryById(@RequestParam(name="id",required=true) String id) {
		LinkWeiboPhoneDetectionLog linkWeiboPhoneDetectionLog = linkWeiboPhoneDetectionLogService.getById(id);
		if(linkWeiboPhoneDetectionLog==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(linkWeiboPhoneDetectionLog);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param linkWeiboPhoneDetectionLog
    */
    @RequiresPermissions("linkweibophonedetectionlog:link_weibo_phone_detection_log:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, LinkWeiboPhoneDetectionLog linkWeiboPhoneDetectionLog) {
        return super.exportXls(request, linkWeiboPhoneDetectionLog, LinkWeiboPhoneDetectionLog.class, "微博手机号检测日志");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("linkweibophonedetectionlog:link_weibo_phone_detection_log:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, LinkWeiboPhoneDetectionLog.class);
    }

}
