package org.jeecg.modules.demo.linkwhitelist.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.linkwhitelist.entity.LinkWhiteList;
import org.jeecg.modules.demo.linkwhitelist.service.ILinkWhiteListService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.modules.demo.mainsite.entity.MainSite;
import org.jeecg.modules.demo.mainsite.service.IMainSiteService;
import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 白单名链接
 * @Author: jeecg-boot
 * @Date:   2023-04-12
 * @Version: V1.0
 */
@Api(tags="白单名链接")
@RestController
@RequestMapping("/linkwhitelist/linkWhiteList")
@Slf4j
public class LinkWhiteListController extends JeecgController<LinkWhiteList, ILinkWhiteListService> {
	@Autowired
	private ILinkWhiteListService linkWhiteListService;

	@Autowired
	private IMainSiteService iMainSiteService;
	
	/**
	 * 分页列表查询
	 *
	 * @param linkWhiteList
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "白单名链接-分页列表查询")
	@ApiOperation(value="白单名链接-分页列表查询", notes="白单名链接-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<LinkWhiteList>> queryPageList(LinkWhiteList linkWhiteList,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<LinkWhiteList> queryWrapper = QueryGenerator.initQueryWrapper(linkWhiteList, req.getParameterMap());
		Page<LinkWhiteList> page = new Page<LinkWhiteList>(pageNo, pageSize);
		IPage<LinkWhiteList> pageList = linkWhiteListService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param linkWhiteList
	 * @return
	 */
	@AutoLog(value = "白单名链接-添加")
	@ApiOperation(value="白单名链接-添加", notes="白单名链接-添加")
	@RequiresPermissions("linkwhitelist:link_white_list:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody LinkWhiteList linkWhiteList) {
		try {
			String mainSiteId = linkWhiteList.getMainSiteId();
			MainSite mainSite = iMainSiteService.getById(mainSiteId);
			linkWhiteList.setMainSiteName(mainSite.getMainSiteName());
			linkWhiteList.setMainSiteUrl(mainSite.getMainSiteUrl());
		}catch (Exception e){
			e.printStackTrace();
		}
		linkWhiteListService.save(linkWhiteList);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param linkWhiteList
	 * @return
	 */
	@AutoLog(value = "白单名链接-编辑")
	@ApiOperation(value="白单名链接-编辑", notes="白单名链接-编辑")
	@RequiresPermissions("linkwhitelist:link_white_list:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody LinkWhiteList linkWhiteList) {
		try {
			String mainSiteId = linkWhiteList.getMainSiteId();
			MainSite mainSite = iMainSiteService.getById(mainSiteId);
			linkWhiteList.setMainSiteName(mainSite.getMainSiteName());
			linkWhiteList.setMainSiteUrl(mainSite.getMainSiteUrl());
		}catch (Exception e){
			e.printStackTrace();
		}
		linkWhiteListService.updateById(linkWhiteList);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "白单名链接-通过id删除")
	@ApiOperation(value="白单名链接-通过id删除", notes="白单名链接-通过id删除")
	@RequiresPermissions("linkwhitelist:link_white_list:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		linkWhiteListService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "白单名链接-批量删除")
	@ApiOperation(value="白单名链接-批量删除", notes="白单名链接-批量删除")
	@RequiresPermissions("linkwhitelist:link_white_list:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.linkWhiteListService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "白单名链接-通过id查询")
	@ApiOperation(value="白单名链接-通过id查询", notes="白单名链接-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<LinkWhiteList> queryById(@RequestParam(name="id",required=true) String id) {
		LinkWhiteList linkWhiteList = linkWhiteListService.getById(id);
		if(linkWhiteList==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(linkWhiteList);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param linkWhiteList
    */
    @RequiresPermissions("linkwhitelist:link_white_list:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, LinkWhiteList linkWhiteList) {
        return super.exportXls(request, linkWhiteList, LinkWhiteList.class, "白单名链接");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("linkwhitelist:link_white_list:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, LinkWhiteList.class);
    }

}
