package org.jeecg.modules.demo.linkwhiterulelist.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.linkwhiterulelist.entity.LinkWhiteRuleList;
import org.jeecg.modules.demo.linkwhiterulelist.service.ILinkWhiteRuleListService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.modules.demo.mainsite.entity.MainSite;
import org.jeecg.modules.demo.mainsite.service.IMainSiteService;
import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 链接表单名规则
 * @Author: jeecg-boot
 * @Date:   2023-11-09
 * @Version: V1.0
 */
@Api(tags="链接表单名规则")
@RestController
@RequestMapping("/linkwhiterulelist/linkWhiteRuleList")
@Slf4j
public class LinkWhiteRuleListController extends JeecgController<LinkWhiteRuleList, ILinkWhiteRuleListService> {
	@Autowired
	private ILinkWhiteRuleListService linkWhiteRuleListService;
	 @Autowired
	 private IMainSiteService iMainSiteService;
	/**
	 * 分页列表查询
	 *
	 * @param linkWhiteRuleList
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "链接表单名规则-分页列表查询")
	@ApiOperation(value="链接表单名规则-分页列表查询", notes="链接表单名规则-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<LinkWhiteRuleList>> queryPageList(LinkWhiteRuleList linkWhiteRuleList,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<LinkWhiteRuleList> queryWrapper = QueryGenerator.initQueryWrapper(linkWhiteRuleList, req.getParameterMap());
		Page<LinkWhiteRuleList> page = new Page<LinkWhiteRuleList>(pageNo, pageSize);
		IPage<LinkWhiteRuleList> pageList = linkWhiteRuleListService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param linkWhiteRuleList
	 * @return
	 */
	@AutoLog(value = "链接表单名规则-添加")
	@ApiOperation(value="链接表单名规则-添加", notes="链接表单名规则-添加")
	@RequiresPermissions("linkwhiterulelist:link_white_rule_list:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody LinkWhiteRuleList linkWhiteRuleList) {
		try {
			String mainSiteId = linkWhiteRuleList.getMainSiteId();
			MainSite mainSite = iMainSiteService.getById(mainSiteId);
			linkWhiteRuleList.setMainSiteName(mainSite.getMainSiteName());
			linkWhiteRuleList.setMainSiteUrl(mainSite.getMainSiteUrl());
		}catch (Exception e){
			e.printStackTrace();
		}
		linkWhiteRuleListService.save(linkWhiteRuleList);
		return Result.OK("添加成功！");
	}
	/**
	 *  编辑
	 *
	 * @param linkWhiteRuleList
	 * @return
	 */
	@AutoLog(value = "链接表单名规则-编辑")
	@ApiOperation(value="链接表单名规则-编辑", notes="链接表单名规则-编辑")
	@RequiresPermissions("linkwhiterulelist:link_white_rule_list:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody LinkWhiteRuleList linkWhiteRuleList) {
		try {
			String mainSiteId = linkWhiteRuleList.getMainSiteId();
			MainSite mainSite = iMainSiteService.getById(mainSiteId);
			linkWhiteRuleList.setMainSiteName(mainSite.getMainSiteName());
			linkWhiteRuleList.setMainSiteUrl(mainSite.getMainSiteUrl());
		}catch (Exception e){
			e.printStackTrace();
		}
		linkWhiteRuleListService.updateById(linkWhiteRuleList);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "链接表单名规则-通过id删除")
	@ApiOperation(value="链接表单名规则-通过id删除", notes="链接表单名规则-通过id删除")
	@RequiresPermissions("linkwhiterulelist:link_white_rule_list:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		linkWhiteRuleListService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "链接表单名规则-批量删除")
	@ApiOperation(value="链接表单名规则-批量删除", notes="链接表单名规则-批量删除")
	@RequiresPermissions("linkwhiterulelist:link_white_rule_list:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.linkWhiteRuleListService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "链接表单名规则-通过id查询")
	@ApiOperation(value="链接表单名规则-通过id查询", notes="链接表单名规则-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<LinkWhiteRuleList> queryById(@RequestParam(name="id",required=true) String id) {
		LinkWhiteRuleList linkWhiteRuleList = linkWhiteRuleListService.getById(id);
		if(linkWhiteRuleList==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(linkWhiteRuleList);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param linkWhiteRuleList
    */
    @RequiresPermissions("linkwhiterulelist:link_white_rule_list:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, LinkWhiteRuleList linkWhiteRuleList) {
        return super.exportXls(request, linkWhiteRuleList, LinkWhiteRuleList.class, "链接表单名规则");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("linkwhiterulelist:link_white_rule_list:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, LinkWhiteRuleList.class);
    }

}
