package org.jeecg.modules.demo.mainsite.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.mainsite.entity.MainSite;
import org.jeecg.modules.demo.mainsite.service.IMainSiteService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 主站点表
 * @Author: jeecg-boot
 * @Date:   2023-04-13
 * @Version: V1.0
 */
@Api(tags="主站点表")
@RestController
@RequestMapping("/mainsite/mainSite")
@Slf4j
public class MainSiteController extends JeecgController<MainSite, IMainSiteService> {
	@Autowired
	private IMainSiteService mainSiteService;
	
	/**
	 * 分页列表查询
	 *
	 * @param mainSite
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	@GetMapping(value = "/list")
	public Result<IPage<MainSite>> queryPageList(MainSite mainSite,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<MainSite> queryWrapper = QueryGenerator.initQueryWrapper(mainSite, req.getParameterMap());
		Page<MainSite> page = new Page<MainSite>(pageNo, pageSize);
		IPage<MainSite> pageList = mainSiteService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param mainSite
	 * @return
	 */
	@AutoLog(value = "主站点表-添加")
	@ApiOperation(value="主站点表-添加", notes="主站点表-添加")
	@RequiresPermissions("mainsite:main_site:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody MainSite mainSite) {
		mainSiteService.save(mainSite);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param mainSite
	 * @return
	 */
	@AutoLog(value = "主站点表-编辑")
	@ApiOperation(value="主站点表-编辑", notes="主站点表-编辑")
	@RequiresPermissions("mainsite:main_site:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody MainSite mainSite) {
		mainSiteService.updateById(mainSite);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "主站点表-通过id删除")
	@ApiOperation(value="主站点表-通过id删除", notes="主站点表-通过id删除")
	@RequiresPermissions("mainsite:main_site:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		mainSiteService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "主站点表-批量删除")
	@ApiOperation(value="主站点表-批量删除", notes="主站点表-批量删除")
	@RequiresPermissions("mainsite:main_site:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.mainSiteService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "主站点表-通过id查询")
	@ApiOperation(value="主站点表-通过id查询", notes="主站点表-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<MainSite> queryById(@RequestParam(name="id",required=true) String id) {
		MainSite mainSite = mainSiteService.getById(id);
		if(mainSite==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(mainSite);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param mainSite
    */
    @RequiresPermissions("mainsite:main_site:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, MainSite mainSite) {
        return super.exportXls(request, mainSite, MainSite.class, "主站点表");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("mainsite:main_site:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, MainSite.class);
    }

}
