package org.jeecg.modules.demo.wechaterrorwordstatistics.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.wechaterrorwordstatistics.entity.WechatErrorWordStatistics;
import org.jeecg.modules.demo.wechaterrorwordstatistics.service.IWechatErrorWordStatisticsService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 微信错敏词统计信息
 * @Author: jeecg-boot
 * @Date:   2023-06-30
 * @Version: V1.0
 */
@Api(tags="微信错敏词统计信息")
@RestController
@RequestMapping("/wechaterrorwordstatistics/wechatErrorWordStatistics")
@Slf4j
public class WechatErrorWordStatisticsController extends JeecgController<WechatErrorWordStatistics, IWechatErrorWordStatisticsService> {
	@Autowired
	private IWechatErrorWordStatisticsService wechatErrorWordStatisticsService;
	
	/**
	 * 分页列表查询
	 *
	 * @param wechatErrorWordStatistics
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "微信错敏词统计信息-分页列表查询")
	@ApiOperation(value="微信错敏词统计信息-分页列表查询", notes="微信错敏词统计信息-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<WechatErrorWordStatistics>> queryPageList(WechatErrorWordStatistics wechatErrorWordStatistics,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<WechatErrorWordStatistics> queryWrapper = QueryGenerator.initQueryWrapper(wechatErrorWordStatistics, req.getParameterMap());
		Page<WechatErrorWordStatistics> page = new Page<WechatErrorWordStatistics>(pageNo, pageSize);
		IPage<WechatErrorWordStatistics> pageList = wechatErrorWordStatisticsService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param wechatErrorWordStatistics
	 * @return
	 */
	@AutoLog(value = "微信错敏词统计信息-添加")
	@ApiOperation(value="微信错敏词统计信息-添加", notes="微信错敏词统计信息-添加")
	@RequiresPermissions("wechaterrorwordstatistics:wechat_error_word_statistics:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody WechatErrorWordStatistics wechatErrorWordStatistics) {
		wechatErrorWordStatisticsService.save(wechatErrorWordStatistics);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param wechatErrorWordStatistics
	 * @return
	 */
	@AutoLog(value = "微信错敏词统计信息-编辑")
	@ApiOperation(value="微信错敏词统计信息-编辑", notes="微信错敏词统计信息-编辑")
	@RequiresPermissions("wechaterrorwordstatistics:wechat_error_word_statistics:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody WechatErrorWordStatistics wechatErrorWordStatistics) {
		wechatErrorWordStatisticsService.updateById(wechatErrorWordStatistics);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "微信错敏词统计信息-通过id删除")
	@ApiOperation(value="微信错敏词统计信息-通过id删除", notes="微信错敏词统计信息-通过id删除")
	@RequiresPermissions("wechaterrorwordstatistics:wechat_error_word_statistics:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		wechatErrorWordStatisticsService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "微信错敏词统计信息-批量删除")
	@ApiOperation(value="微信错敏词统计信息-批量删除", notes="微信错敏词统计信息-批量删除")
	@RequiresPermissions("wechaterrorwordstatistics:wechat_error_word_statistics:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.wechatErrorWordStatisticsService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "微信错敏词统计信息-通过id查询")
	@ApiOperation(value="微信错敏词统计信息-通过id查询", notes="微信错敏词统计信息-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<WechatErrorWordStatistics> queryById(@RequestParam(name="id",required=true) String id) {
		WechatErrorWordStatistics wechatErrorWordStatistics = wechatErrorWordStatisticsService.getById(id);
		if(wechatErrorWordStatistics==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(wechatErrorWordStatistics);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param wechatErrorWordStatistics
    */
    @RequiresPermissions("wechaterrorwordstatistics:wechat_error_word_statistics:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, WechatErrorWordStatistics wechatErrorWordStatistics) {
        return super.exportXls(request, wechatErrorWordStatistics, WechatErrorWordStatistics.class, "微信错敏词统计信息");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("wechaterrorwordstatistics:wechat_error_word_statistics:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, WechatErrorWordStatistics.class);
    }

}
