package org.jeecg.modules.demo.wechatpostswordlog.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.wechatpostswordlog.entity.WechatPostsWordLog;
import org.jeecg.modules.demo.wechatpostswordlog.service.IWechatPostsWordLogService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 微信公众号文章错敏词日志
 * @Author: jeecg-boot
 * @Date:   2023-05-22
 * @Version: V1.0
 */
@Api(tags="微信公众号文章错敏词日志")
@RestController
@RequestMapping("/wechatpostswordlog/wechatPostsWordLog")
@Slf4j
public class WechatPostsWordLogController extends JeecgController<WechatPostsWordLog, IWechatPostsWordLogService> {
	@Autowired
	private IWechatPostsWordLogService wechatPostsWordLogService;
	
	/**
	 * 分页列表查询
	 *
	 * @param wechatPostsWordLog
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "微信公众号文章错敏词日志-分页列表查询")
	@ApiOperation(value="微信公众号文章错敏词日志-分页列表查询", notes="微信公众号文章错敏词日志-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<WechatPostsWordLog>> queryPageList(WechatPostsWordLog wechatPostsWordLog,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<WechatPostsWordLog> queryWrapper = QueryGenerator.initQueryWrapper(wechatPostsWordLog, req.getParameterMap());
		Page<WechatPostsWordLog> page = new Page<WechatPostsWordLog>(pageNo, pageSize);
		IPage<WechatPostsWordLog> pageList = wechatPostsWordLogService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param wechatPostsWordLog
	 * @return
	 */
	@AutoLog(value = "微信公众号文章错敏词日志-添加")
	@ApiOperation(value="微信公众号文章错敏词日志-添加", notes="微信公众号文章错敏词日志-添加")
	@RequiresPermissions("wechatpostswordlog:wechat_posts_word_log:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody WechatPostsWordLog wechatPostsWordLog) {
		wechatPostsWordLogService.save(wechatPostsWordLog);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param wechatPostsWordLog
	 * @return
	 */
	@AutoLog(value = "微信公众号文章错敏词日志-编辑")
	@ApiOperation(value="微信公众号文章错敏词日志-编辑", notes="微信公众号文章错敏词日志-编辑")
	@RequiresPermissions("wechatpostswordlog:wechat_posts_word_log:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody WechatPostsWordLog wechatPostsWordLog) {
		wechatPostsWordLogService.updateById(wechatPostsWordLog);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "微信公众号文章错敏词日志-通过id删除")
	@ApiOperation(value="微信公众号文章错敏词日志-通过id删除", notes="微信公众号文章错敏词日志-通过id删除")
	@RequiresPermissions("wechatpostswordlog:wechat_posts_word_log:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		wechatPostsWordLogService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "微信公众号文章错敏词日志-批量删除")
	@ApiOperation(value="微信公众号文章错敏词日志-批量删除", notes="微信公众号文章错敏词日志-批量删除")
	@RequiresPermissions("wechatpostswordlog:wechat_posts_word_log:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.wechatPostsWordLogService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "微信公众号文章错敏词日志-通过id查询")
	@ApiOperation(value="微信公众号文章错敏词日志-通过id查询", notes="微信公众号文章错敏词日志-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<WechatPostsWordLog> queryById(@RequestParam(name="id",required=true) String id) {
		WechatPostsWordLog wechatPostsWordLog = wechatPostsWordLogService.getById(id);
		if(wechatPostsWordLog==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(wechatPostsWordLog);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param wechatPostsWordLog
    */
    @RequiresPermissions("wechatpostswordlog:wechat_posts_word_log:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, WechatPostsWordLog wechatPostsWordLog) {
        return super.exportXls(request, wechatPostsWordLog, WechatPostsWordLog.class, "微信公众号文章错敏词日志");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("wechatpostswordlog:wechat_posts_word_log:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, WechatPostsWordLog.class);
    }

}
