package org.jeecg.modules.demo.weibouser.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.weibouser.entity.WeiboUser;
import org.jeecg.modules.demo.weibouser.service.IWeiboUserService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 微博用户管理
 * @Author: jeecg-boot
 * @Date:   2023-05-08
 * @Version: V1.0
 */
@Api(tags="微博用户管理")
@RestController
@RequestMapping("/weibouser/weiboUser")
@Slf4j
public class WeiboUserController extends JeecgController<WeiboUser, IWeiboUserService> {
	@Autowired
	private IWeiboUserService weiboUserService;
	
	/**
	 * 分页列表查询
	 *
	 * @param weiboUser
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "微博用户管理-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<WeiboUser>> queryPageList(WeiboUser weiboUser,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<WeiboUser> queryWrapper = QueryGenerator.initQueryWrapper(weiboUser, req.getParameterMap());
		Page<WeiboUser> page = new Page<WeiboUser>(pageNo, pageSize);
		IPage<WeiboUser> pageList = weiboUserService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param weiboUser
	 * @return
	 */
	@AutoLog(value = "微博用户管理-添加")
	@ApiOperation(value="微博用户管理-添加", notes="微博用户管理-添加")
	@RequiresPermissions("weibouser:weibo_user:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody WeiboUser weiboUser) {
		weiboUserService.save(weiboUser);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param weiboUser
	 * @return
	 */
	@AutoLog(value = "微博用户管理-编辑")
	@ApiOperation(value="微博用户管理-编辑", notes="微博用户管理-编辑")
	@RequiresPermissions("weibouser:weibo_user:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody WeiboUser weiboUser) {
		weiboUserService.updateById(weiboUser);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "微博用户管理-通过id删除")
	@ApiOperation(value="微博用户管理-通过id删除", notes="微博用户管理-通过id删除")
	@RequiresPermissions("weibouser:weibo_user:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		weiboUserService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "微博用户管理-批量删除")
	@ApiOperation(value="微博用户管理-批量删除", notes="微博用户管理-批量删除")
	@RequiresPermissions("weibouser:weibo_user:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.weiboUserService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "微博用户管理-通过id查询")
	@ApiOperation(value="微博用户管理-通过id查询", notes="微博用户管理-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<WeiboUser> queryById(@RequestParam(name="id",required=true) String id) {
		WeiboUser weiboUser = weiboUserService.getById(id);
		if(weiboUser==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(weiboUser);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param weiboUser
    */
    @RequiresPermissions("weibouser:weibo_user:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, WeiboUser weiboUser) {
        return super.exportXls(request, weiboUser, WeiboUser.class, "微博用户管理");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("weibouser:weibo_user:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, WeiboUser.class);
    }

}
