package org.jeecg.modules.demo.ylpatientmember.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.ylpatientmember.entity.YlPatientMember;
import org.jeecg.modules.demo.ylpatientmember.service.IYlPatientMemberService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 患者会员管理
 * @Author: jeecg-boot
 * @Date:   2023-04-09
 * @Version: V1.0
 */
@Api(tags="患者会员管理")
@RestController
@RequestMapping("/ylpatientmember/ylPatientMember")
@Slf4j
public class YlPatientMemberController extends JeecgController<YlPatientMember, IYlPatientMemberService> {
	@Autowired
	private IYlPatientMemberService ylPatientMemberService;
	
	/**
	 * 分页列表查询
	 *
	 * @param ylPatientMember
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "患者会员管理-分页列表查询")
	@ApiOperation(value="患者会员管理-分页列表查询", notes="患者会员管理-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<YlPatientMember>> queryPageList(YlPatientMember ylPatientMember,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<YlPatientMember> queryWrapper = QueryGenerator.initQueryWrapper(ylPatientMember, req.getParameterMap());
		Page<YlPatientMember> page = new Page<YlPatientMember>(pageNo, pageSize);
		IPage<YlPatientMember> pageList = ylPatientMemberService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param ylPatientMember
	 * @return
	 */
	@AutoLog(value = "患者会员管理-添加")
	@ApiOperation(value="患者会员管理-添加", notes="患者会员管理-添加")
	//@RequiresPermissions("org.jeecg.modules.demo:yl_patient_member:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody YlPatientMember ylPatientMember) {
		ylPatientMemberService.save(ylPatientMember);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param ylPatientMember
	 * @return
	 */
	@AutoLog(value = "患者会员管理-编辑")
	@ApiOperation(value="患者会员管理-编辑", notes="患者会员管理-编辑")
	//@RequiresPermissions("org.jeecg.modules.demo:yl_patient_member:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody YlPatientMember ylPatientMember) {
		ylPatientMemberService.updateById(ylPatientMember);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "患者会员管理-通过id删除")
	@ApiOperation(value="患者会员管理-通过id删除", notes="患者会员管理-通过id删除")
	//@RequiresPermissions("org.jeecg.modules.demo:yl_patient_member:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		ylPatientMemberService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "患者会员管理-批量删除")
	@ApiOperation(value="患者会员管理-批量删除", notes="患者会员管理-批量删除")
	//@RequiresPermissions("org.jeecg.modules.demo:yl_patient_member:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.ylPatientMemberService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "患者会员管理-通过id查询")
	@ApiOperation(value="患者会员管理-通过id查询", notes="患者会员管理-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<YlPatientMember> queryById(@RequestParam(name="id",required=true) String id) {
		YlPatientMember ylPatientMember = ylPatientMemberService.getById(id);
		if(ylPatientMember==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(ylPatientMember);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param ylPatientMember
    */
    //@RequiresPermissions("org.jeecg.modules.demo:yl_patient_member:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, YlPatientMember ylPatientMember) {
        return super.exportXls(request, ylPatientMember, YlPatientMember.class, "患者会员管理");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    //@RequiresPermissions("yl_patient_member:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, YlPatientMember.class);
    }

}
